# Pytorch Functional

> THIS PROJECT WAS RENAMED!
>
> New name is Pytorch Symbolic.
>
> The main reason is the ambiguity with `torch.nn.functional`.

## NEW LINKS

* https://pytorch-symbolic.readthedocs.io/
* https://github.com/gahaalt/pytorch-symbolic/
* https://pypi.org/project/pytorch-symbolic/

## Installation

Install new version with pip:

```
pip install pytorch-symbolic
```
